@@ -1,4 +1,4 @@
-#' Fit Bayesian Inference for Multivariate Meta-Regression With a Partially Observed Within-Study Sample Covariance Matrix
+#' Fit Bayesian Inference for Meta-Regression
 #'
 #' This is a function for running the Markov chain Monte Carlo algorithm for the *Bayesian inference for multivariate meta-regression with a partially observed within-study sample covariance matrix* model. The first six arguments are required.
 #' fmodel can be one of 5 numbers: 1, 2, 3, 4, and 5. The first model, fmodel = 1 denoted by M1, indicates that the \eqn{\Sigma_{tk}}
@@ -43,7 +43,7 @@
 #' + `Outcome` - the aggregate response used in the function call.
 #' + `SD` - the standard deviation used in the function call.
 #' + `Npt` - the number of participants for `(t,k)` used in the function call.
-#' + `XCovariate` - the aggregate design matrix for fixed effects used in the function call. Depending on `scale_x`, this may differ from #' the matrix provided at function call.
+#' + `XCovariate` - the aggregate design matrix for fixed effects used in the function call. Depending on `scale_x`, this may differ from the matrix provided at function call.
 #' + `WCovariate` - the aggregate design matrix for random effects.
 #' + `Treat` - the *renumbered* treatment indicators. Depending on `Treat_order`, it may differ from the vector provided at function call.
 #' + `Trial` - the *renumbered* trial indicators. Depending on `Trial_order`, it may differ from the vector provided at function call.
@@ -66,20 +66,21 @@
 #' data("cholesterol")
 #' Outcome <- model.matrix(~ 0 + pldlc + phdlc + ptg, data = cholesterol)
 #' SD <- model.matrix(~ 0 + sdldl + sdhdl + sdtg, data = cholesterol)
-#' Trial <- cholesterol$Trial
-#' Treat <- cholesterol$trt
-#' Npt <- cholesterol$Npt
+#' Trial <- cholesterol$trial
+#' Treat <- cholesterol$treat
+#' Npt <- cholesterol$n
 #' XCovariate <- model.matrix(~ 0 + bldlc + bhdlc + btg + age + durat +
 #'  white + male + dm, data = cholesterol)
-#' WCovariate <- model.matrix(~ trt, data = cholesterol)
+#' WCovariate <- model.matrix(~ treat, data = cholesterol)
 #' 
 #' fmodel <- 1
 #' set.seed(2797542)
 #' fit <- bayes.parobs(Outcome, SD, XCovariate, WCovariate, Treat, Trial,
 #'    Npt, fmodel, mcmc = list(ndiscard = 1, nskip = 1, nkeep = 1),
 #'    scale_x = TRUE, group = cholesterol$onstat, verbose = FALSE)
-#' @importFrom stats model.matrix optim
+#' @importFrom stats model.matrix
 #' @importFrom methods is
+#' @seealso \code{\link{bmeta_analyze}} for using the \code{\link[Formula]{Formula}} interface
 #' @md
 #' @export
 bayes.parobs <- function(Outcome, SD, XCovariate, WCovariate, Treat, Trial, Npt, fmodel = 1, prior = list(), mcmc = list(), control = list(), init = list(), Treat_order = NULL, Trial_order = NULL, group = NULL, group_order = NULL, scale_x = FALSE, verbose = FALSE) {
@@ -135,7 +136,7 @@ bayes.parobs <- function(Outcome, SD, XCovariate, WCovariate, Treat, Trial, Npt,
     second.exist <- TRUE
     sl <- unique(group)
     if (length(sl) != 2) {
-      stop("The second-line trial indicators must be binary.")
+      stop(paste(sQuote("group"), "must be binary"))
     }
     nr <- 2
     if (is.null(group_order)) {
@@ -155,7 +156,7 @@ bayes.parobs <- function(Outcome, SD, XCovariate, WCovariate, Treat, Trial, Npt,
   ndiscard <- mcvals$ndiscard
   nskip <- mcvals$nskip
   if (nskip < 1) {
-    stop("The thinning cannot be smaller than 1.")
+    stop(paste0(sQuote("nskip"), "can't be smaller than 1"))
   }
   nkeep <- mcvals$nkeep
 
@@ -212,12 +213,27 @@ bayes.parobs <- function(Outcome, SD, XCovariate, WCovariate, Treat, Trial, Npt,
   gamR_init <- init_final$gamR
   Omega_init <- init_final$Omega
   Rho_init <- init_final$Rho
+  if (length(theta_init) != (xcols + nw*nr) * J) {
+    stop(paste("theta initialized with length", sQuote(length(theta_init)), "but", sQuote((xcols + nw*nr) * J), "wanted"))
+  }
+  if (dim(Omega_init)[1] != nw*nr*J || dim(Omega_init)[2] != nw*nr*J) {
+    stop(paste("Omega initialized with dimensions", sQuote(dim(Omega_init)), "but", sQuote(nw*nr*J), "wanted"))
+  }
+  if (dim(Rho_init)[1] != J || dim(Rho_init)[2] != J) {
+    stop(paste("Rho initialized with dimensions", sQuote(dim(Rho_init)), "but", sQuote(J), "wanted"))
+  }
+  if (dim(gamR_init)[1] != nw*nr*J) {
+    stop(paste("gamR initialized with", sQuote(dim(gamR_init)[1]), "rows but", sQuote(nw*nr*J), "wanted"))
+  }
+  if (dim(gamR_init)[2] != K) {
+    stop(paste("gamR initialized with", sQuote(dim(gamR_init)[2]), "columns but", sQuote(K), "wanted"))
+  }
 
   if (any(eigen(Omega_init, symmetric = TRUE, only.values = TRUE)$values <= 0)) {
-    stop("The initial value for Omega is not positive definite")
+    stop(paste("The initial value for", sQuote("Omega"), "is not positive definite"))
   }
   if (any(eigen(Rho_init, symmetric = TRUE, only.values = TRUE)$values <= 0)) {
-    stop("The initial value for Omega is not positive definite")
+    stop(paste("The initial value for", sQuote("Rho"), "is not positive definite"))
   }
   
   if (scale_x) {
@@ -226,6 +242,8 @@ bayes.parobs <- function(Outcome, SD, XCovariate, WCovariate, Treat, Trial, Npt,
     XCovariate_ <- XCovariate
   }
 
+  
+
   mcmctime <- system.time({
     if (second.exist) {
       if (fmodel == 1) {
@@ -370,7 +388,7 @@ bayes.parobs <- function(Outcome, SD, XCovariate, WCovariate, Treat, Trial, Npt,
           as.logical(verbose)
         )
       } else {
-        stop("`fmodel` is invalid. Please pick from {1, 2, 3, 4, 5}.")
+        stop(paste(sQuote("fmodel"), "is invalid. Please pick from {1, 2, 3, 4, 5}"))
       }
     } else {
       if (fmodel == 1) {
@@ -510,7 +528,7 @@ bayes.parobs <- function(Outcome, SD, XCovariate, WCovariate, Treat, Trial, Npt,
           as.logical(verbose)
         )
       } else {
-        stop("`fmodel` is invalid. Please pick from {1, 2, 3, 4, 5}.")
+        stop(paste(sQuote("fmodel"), "is invalid. Please pick from {1, 2, 3, 4, 5}"))
       }
     }
   })
