@@ -7,7 +7,6 @@
 #include <iterator>
 #include <progress.hpp>
 #include <progress_bar.hpp>
-#include "random.h"
 #include "linearalgebra.h"
 #include "misc_nmr.h"
 #include "nelmin.h"
@@ -19,8 +18,8 @@ Rcpp::List BayesNMR(const arma::vec& y,
 					const arma::vec& sd,
 					const arma::mat& x,
 					const arma::mat& z,
-					const arma::uvec& ids,
-					const arma::uvec& iarm,
+					const arma::uvec& ids, // study id (trial indicators)
+					const arma::uvec& iarm, // arm id (treatment indicators)
 					const arma::vec& npt,
 					const double& nu, // = degrees of freedom
 					const double& c01_inv,
