@@ -7,8 +7,6 @@
 #include <iterator>
 #include <progress.hpp>
 #include <progress_bar.hpp>
-#include "misc.h"
-#include "random.h"
 #include "linearalgebra.h"
 #include "loglik_POCov.h"
 #include "nelmin.h"
@@ -182,7 +180,7 @@ Rcpp::List fmodel2(const arma::mat& Outcome,
 			for (int jj = 0; jj < J; ++jj) {
 				mat gamstar = gamR.rows(nw*jj, nw*(jj+1)-1);
 				mat qq = Omega0inv + (gamstar * gamstar.t());
-				mat ominv = RNG::rwish(shape_omega, arma::inv_sympd(qq));
+				mat ominv = arma::wishrnd(arma::inv_sympd(qq), shape_omega);
 				mat om = arma::inv_sympd(ominv);
 				Omegainv(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = ominv;
 				Omega(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = om;
@@ -206,7 +204,7 @@ Rcpp::List fmodel2(const arma::mat& Outcome,
 				vec resid_i = arma::trans(resid.row(i)) - W * gam_k;
 				qq += ntk * resid_i * resid_i.t() + (ntk - 1.0) * V * R * V;
 			}
-			Siginv = RNG::rwish(df, arma::inv_sympd(qq));
+			Siginv = arma::wishrnd(arma::inv_sympd(qq), df);
 
 			for (int i = 0; i < N; ++i) {
 				rowvec y_i = Outcome.row(i);
@@ -377,7 +375,7 @@ Rcpp::List fmodel2(const arma::mat& Outcome,
 				for (int jj = 0; jj < J; ++jj) {
 					mat gamstar = gamR.rows(nw*jj, nw*(jj+1)-1);
 					mat qq = Omega0inv + (gamstar * gamstar.t());
-					mat ominv = RNG::rwish(shape_omega, arma::inv_sympd(qq));
+					mat ominv = arma::wishrnd(arma::inv_sympd(qq), shape_omega);
 					mat om = arma::inv_sympd(ominv);
 					Omegainv(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = ominv;
 					Omega(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = om;
@@ -402,7 +400,7 @@ Rcpp::List fmodel2(const arma::mat& Outcome,
 					resid_ikeep.row(i) = resid_i.t();
 					qq += ntk * resid_i * resid_i.t() + (ntk - 1.0) * V * R * V;
 				}
-				Siginv = RNG::rwish(df, arma::inv_sympd(qq));
+				Siginv = arma::wishrnd(arma::inv_sympd(qq), df);
 				Sig = arma::inv_sympd(Siginv);
 
 				for (int i = 0; i < N; ++i) {
