@@ -7,8 +7,6 @@
 #include <iterator>
 #include <progress.hpp>
 #include <progress_bar.hpp>
-#include "misc.h"
-#include "random.h"
 #include "linearalgebra.h"
 #include "loglik_POCov.h"
 #include "nelmin.h"
@@ -195,7 +193,7 @@ Rcpp::List fmodel2p5(const arma::mat& Outcome,
 			for (int jj = 0; jj < J; ++jj) {
 				mat gamstar = gamR.rows(nw*jj, nw*(jj+1)-1);
 				mat qq = Omega0inv + (gamstar * gamstar.t());
-				mat ominv = RNG::rwish(shape_omega, arma::inv_sympd(qq));
+				mat ominv = arma::wishrnd(arma::inv_sympd(qq), shape_omega);
 				mat om = arma::inv_sympd(ominv);
 				Omegainv(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = ominv;
 				Omega(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = om;
@@ -225,7 +223,7 @@ Rcpp::List fmodel2p5(const arma::mat& Outcome,
 					vec resid_i = arma::trans(resid.row(i_t)) - W * gam_k;
 					qq += ntk * resid_i * resid_i.t() + (ntk - 1.0) * V * R * V;
 				}
-				Siginv.col(t) = vech(RNG::rwish(s0 + nt_dot, arma::inv_sympd(qq)));
+				Siginv.col(t) = vech(arma::wishrnd(arma::inv_sympd(qq), s0 + nt_dot));
 			}
 
 			for (int i = 0; i < N; ++i) {
@@ -402,7 +400,7 @@ Rcpp::List fmodel2p5(const arma::mat& Outcome,
 				for (int jj = 0; jj < J; ++jj) {
 					mat gamstar = gamR.rows(nw*jj, nw*(jj+1)-1);
 					mat qq = Omega0inv + (gamstar * gamstar.t());
-					mat ominv = RNG::rwish(shape_omega, arma::inv_sympd(qq));
+					mat ominv = arma::wishrnd(arma::inv_sympd(qq), shape_omega);
 					mat om = arma::inv_sympd(ominv);
 					Omegainv(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = ominv;
 					Omega(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = om;
@@ -433,7 +431,7 @@ Rcpp::List fmodel2p5(const arma::mat& Outcome,
 						resid_ikeep.row(i_t) = resid_i.t();
 						qq += ntk * resid_i * resid_i.t() + (ntk - 1.0) * V * R * V;
 					}
-					mat Siginv_new = RNG::rwish(s0 + nt_dot, arma::inv_sympd(qq));
+					mat Siginv_new = arma::wishrnd(arma::inv_sympd(qq), s0 + nt_dot);
 					mat Sig_new = arma::inv_sympd(Siginv_new);
 					Siginv.col(t) = vech(Siginv_new);
 					Sig.col(t) = vech(Sig_new);
