@@ -7,9 +7,7 @@
 #include <iterator>
 #include <progress.hpp>
 #include <progress_bar.hpp>
-#include "misc.h"
 #include "ramcmc.h"
-#include "random.h"
 #include "linearalgebra.h"
 #include "loglik_POCov.h"
 #include "nelmin.h"
@@ -207,7 +205,7 @@ Rcpp::List fmodel3(const arma::mat& Outcome,
 			for (int jj = 0; jj < J; ++jj) {
 				mat gamstar = gamR.rows(nw*jj, nw*(jj+1)-1);
 				mat qq = Omega0inv + (gamstar * gamstar.t());
-				mat ominv = RNG::rwish(shape_omega, arma::inv(qq));
+				mat ominv = arma::wishrnd(arma::inv(qq), shape_omega);
 				mat om = arma::inv_sympd(ominv);
 				Omegainv(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = ominv;
 				Omega(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = om;
@@ -559,7 +557,7 @@ Rcpp::List fmodel3(const arma::mat& Outcome,
 				for (int jj = 0; jj < J; ++jj) {
 					mat gamstar = gamR.rows(nw*jj, nw*(jj+1)-1);
 					mat qq = Omega0inv + (gamstar * gamstar.t());
-					mat ominv = RNG::rwish(shape_omega, arma::inv(qq));
+					mat ominv = arma::wishrnd(arma::inv(qq), shape_omega);
 					mat om = arma::inv(ominv);
 					Omegainv(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = ominv;
 					Omega(arma::span(nw*jj, nw*(jj+1)-1), arma::span(nw*jj, nw*(jj+1)-1)) = om;
