@@ -6,7 +6,7 @@
 
 arma::mat vecr(const arma::mat& X) {
 	const int J = X.n_cols;
-	arma::vec vphi((J*(J-1))/2);
+	arma::vec vphi((J*(J-1))/2, arma::fill::zeros);
 	for (int i = 0; i < J-1; ++i) {
 		for (int j = i+1; j < J; ++j) {
 			int k = (J*(J-1)/2) - (J-i)*((J-i)-1)/2 + j - i - 1;
@@ -32,7 +32,7 @@ arma::mat vecrinv(const arma::vec& X, const int& J) {
 arma::vec vecl(const arma::mat& X) {
 	using namespace arma;
 	int n = X.n_rows;
-	arma::vec out(n*(n-1)/2);
+	arma::vec out(n*(n-1)/2, arma::fill::zeros);
 	for (int j = 0; j < n-1; ++j) {
 		for (int i = j+1; i < n; ++i) {
 			out((n-1)*j - (j-1)*j/2 + i - 1 - j) = X(i, j);
@@ -43,7 +43,7 @@ arma::vec vecl(const arma::mat& X) {
 
 arma::vec vech(const arma::mat& X) {
 	int n = X.n_rows;
-	arma::vec out(n*(n+1)/2);
+	arma::vec out(n*(n+1)/2, arma::fill::zeros);
 	for (int j = 0; j < n; ++j) {
 		for (int i = j; i < n; ++i) {
 			out(n*j - (j-1)*j/2 + i - j) = X(i, j);
@@ -68,65 +68,6 @@ arma::mat vechinv(const arma::vec& v, const int& n) {
 	return out;
 }
 
-arma::mat duplicate_matrix (const int& n) {
-  arma::mat mat1 = arma::eye<arma::mat>(n, n);
-  arma::vec index = arma::vectorise(arma::linspace<arma::vec>(1, n*(n+1)/2, n*(n+1)/2));
-  for (int j = 0; j < n; ++j) {
-    for (int i = j; i < n; ++i) {
-      if (j == 0) mat1(i, j) = index(i);
-      else {
-        mat1(i, j) = index(n*j - (j-1)*j/2 + i - j, 0);
-      }
-    }
-  }
-  arma::mat mat2 = arma::symmatl(mat1);
-  arma::vec temp_vec = arma::vectorise(mat2);
-  int t = temp_vec.size();
-  int s = index.size();
-  arma::mat result(t, s);
-  for (int k = 0; k < t; ++k) {
-    for (int u = 0; u < s; ++u) {
-      if (temp_vec(k) == index(u)) result(k, u) = 1;
-      else result(k, u) = 0;
-    }
-  }
-  
-  return result;
-}
-
-arma::vec uppertriv(const arma::mat& A) {
-	using namespace arma;
-	int p = A.n_cols;
-	umat indmx(p, p, fill::ones);
-	for (int i = 0; i < p; ++i) {
-		indmx(i,i) = 0;
-	}
-	indmx = arma::trimatu(indmx);
-	return A.elem(find(indmx > 0));
-}
-
-
-arma::mat blockdiag( arma::field<arma::mat>& x ) {
-	unsigned int n = x.n_rows;
-	int dimen = 0;
-	arma::ivec dimvec(n);
-
-	for (unsigned int i = 0; i < n; ++i) {
-		dimvec(i) = x(i,0).n_rows; 
-		dimen += dimvec(i);
-	}
-
-	arma::mat X(dimen, dimen, arma::fill::zeros);
-	int idx = 0;
-
-	for (unsigned int i = 0; i < n; ++i) {
-		X.submat( idx, idx, idx + dimvec(i) - 1, idx + dimvec(i) - 1 ) = x(i, 0);
-		idx += dimvec(i);
-	}
-
-	return X;
-}
-
 /**************************
 Convert partial correlation
 to correlation
@@ -221,26 +162,3 @@ arma::mat Rho_to_pRho(arma::mat& Rho) {
 	return pRho;
 }
 
-// hyperspherical reparameterization: Rho = B * B'
-arma::mat constructB(const arma::mat& Rangle) {
-	const int J = Rangle.n_cols;
-	arma::mat B(J, J, arma::fill::zeros);
-	for (int j = 0; j < J; ++j) {
-		for (int i = j; i < J; ++i) {
-			if (i == 0 && i == j) {
-				B(i,i) = 1.0;
-			} else if (i != j) {
-				B(i,j) = std::cos(Rangle(i,j));
-				for (int l = 0; l < j; ++l) {
-					B(i,j) *= std::sin(Rangle(i,l));
-				}
-			} else {
-				B(i,i) = 1.0;
-				for (int l = 0; l < i; ++l) {
-					B(i,i) *= std::sin(Rangle(i,l));
-				}
-			}
-		}
-	}
-	return B;
-}
